--#SET TERMINATOR ;

-- =============================================
-- SaveToDB Framework for IBM DB2
-- Version 7.19, March 12, 2018
--
-- This script upgrades SaveToDB Framework 5.x to SaveToDB Framework 7.19
--
-- Copyright 2012-2018 Gartle Technology Corporation
-- =============================================

CREATE OR REPLACE VIEW SAVETODB_DEV.VIEW_QUERY_LIST (
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
    )
AS
SELECT
    TABLE_SCHEMA
    , TABLE_NAME
    , TABLE_TYPE
    , TABLE_CODE
    , INSERT_PROCEDURE
    , UPDATE_PROCEDURE
    , DELETE_PROCEDURE
    , PROCEDURE_TYPE
FROM
(
    (
    SELECT
        t.TABSCHEMA AS TABLE_SCHEMA
        , t.TABNAME AS TABLE_NAME
        , CASE t."TYPE"
            WHEN 'T' THEN 'TABLE'
            WHEN 'V' THEN 'VIEW'
            ELSE TYPE
            END AS TABLE_TYPE
        , NULL AS TABLE_CODE
        , COALESCE(q.INSERT_PROCEDURE, i.PROCEDURE_NAME) AS INSERT_PROCEDURE
        , COALESCE(q.UPDATE_PROCEDURE, u.PROCEDURE_NAME) AS UPDATE_PROCEDURE
        , COALESCE(q.DELETE_PROCEDURE, d.PROCEDURE_NAME) AS DELETE_PROCEDURE
        , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.PROCEDURE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
    FROM
        (
        SELECT
            t.TABSCHEMA
            , t.TABNAME
            , MAX(t."TYPE") AS "TYPE"
        FROM
            SYSCAT.TABLES t
            INNER JOIN SYSCAT.TABAUTH a ON a.TABSCHEMA = t.TABSCHEMA AND a.TABNAME = t.TABNAME
            LEFT OUTER JOIN SYSCAT.ROLEAUTH r ON r.ROLENAME = a.GRANTEE
        WHERE
            t.TABSCHEMA NOT IN ('SYSCAT', 'SYSIBM', 'SYSIBMADM', 'SYSTOOLS', 'SYSSTAT')
            AND t."TYPE" IN ('T', 'V')
            AND a.SELECTAUTH IN ('Y', 'G')
            AND (t.OWNER = USER OR a.GRANTEE = USER OR r.GRANTEE = USER)
        GROUP BY
            t.TABSCHEMA
            , t.TABNAME
        ) t
        LEFT OUTER JOIN SAVETODB_DEV.QUERY_LIST q ON q.TABLE_SCHEMA = t.TABSCHEMA AND q.TABLE_NAME = t.TABNAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_INSERT', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_INSERT'
            ) i ON t.TABSCHEMA = i.ROUTINESCHEMA AND t.TABNAME = i.BASE_NAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_UPDATE', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_UPDATE'
            ) u ON t.TABSCHEMA = u.ROUTINESCHEMA AND t.TABNAME = u.BASE_NAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_DELETE', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_DELETE'
            ) d ON t.TABSCHEMA = d.ROUTINESCHEMA AND t.TABNAME = d.BASE_NAME
    ) UNION ALL (
    SELECT
        t.ROUTINESCHEMA AS TABLE_SCHEMA
        , t.ROUTINENAME AS TABLE_NAME
        , 'PROCEDURE' AS TABLE_TYPE
        , NULL AS TABLE_CODE
        , COALESCE(q.INSERT_PROCEDURE, i.PROCEDURE_NAME) AS INSERT_PROCEDURE
        , COALESCE(q.UPDATE_PROCEDURE, u.PROCEDURE_NAME) AS UPDATE_PROCEDURE
        , COALESCE(q.DELETE_PROCEDURE, d.PROCEDURE_NAME) AS DELETE_PROCEDURE
        , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.PROCEDURE_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
    FROM
        (
        SELECT
            t.ROUTINESCHEMA
            , t.ROUTINENAME
        FROM
            SYSCAT.ROUTINES t
            INNER JOIN SYSCAT.ROUTINEAUTH a ON a.SCHEMA = t.ROUTINESCHEMA AND a.SPECIFICNAME = t.ROUTINENAME
            LEFT OUTER JOIN SYSCAT.ROLEAUTH r ON r.ROLENAME = a.GRANTEE
        WHERE
            t.ROUTINESCHEMA NOT IN ('SYSCAT', 'SYSIBM', 'SYSIBMADM', 'SYSPROC', 'SYSTOOLS', 'SYSSTAT')
            AND t.ROUTINETYPE = 'P'
            AND t.RESULT_SETS = 1
            AND t.LANGUAGE = 'SQL'
            AND t.ROUTINENAME NOT LIKE '%_INSERT'
            AND t.ROUTINENAME NOT LIKE '%_UPDATE'
            AND t.ROUTINENAME NOT LIKE '%_DELETE'
            AND t.ROUTINENAME NOT LIKE '%_MERGE'
            AND t.ROUTINENAME NOT LIKE '%_CHANGE'
            AND a.EXECUTEAUTH IN ('Y', 'G')
            AND (t.OWNER = USER OR a.GRANTEE = USER OR r.GRANTEE = USER)
        GROUP BY
            t.ROUTINESCHEMA
            , t.ROUTINENAME
        ) t
        LEFT OUTER JOIN SAVETODB_DEV.QUERY_LIST q ON q.TABLE_SCHEMA = t.ROUTINESCHEMA AND q.TABLE_NAME = t.ROUTINENAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_INSERT', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_INSERT'
            ) i ON t.ROUTINESCHEMA = i.ROUTINESCHEMA AND REPLACE(t.ROUTINENAME, '_SELECT', '') = i.BASE_NAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_UPDATE', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_UPDATE'
            ) u ON t.ROUTINESCHEMA = u.ROUTINESCHEMA AND REPLACE(t.ROUTINENAME, '_SELECT', '') = u.BASE_NAME
        LEFT OUTER JOIN (
            SELECT ROUTINESCHEMA, REPLACE(ROUTINENAME, '_DELETE', '') AS BASE_NAME, ROUTINESCHEMA || '.' || ROUTINENAME AS PROCEDURE_NAME FROM SYSCAT.ROUTINES
                WHERE ROUTINENAME LIKE '%_DELETE'
            ) d ON t.ROUTINESCHEMA = d.ROUTINESCHEMA AND REPLACE(t.ROUTINENAME, '_SELECT', '') = d.BASE_NAME
    ) UNION ALL (
    SELECT
        q.TABLE_SCHEMA
        , q.TABLE_NAME
        , q.TABLE_TYPE
        , q.TABLE_CODE
        , q.INSERT_PROCEDURE
        , q.UPDATE_PROCEDURE
        , q.DELETE_PROCEDURE
        , q.PROCEDURE_TYPE
    FROM
        SAVETODB_DEV.QUERY_LIST q
        LEFT OUTER JOIN SYSCAT.TABLES t ON q.TABLE_SCHEMA = t.TABSCHEMA AND q.TABLE_NAME = t.TABNAME
        LEFT OUTER JOIN SYSCAT.ROUTINES r ON q.TABLE_SCHEMA = r.ROUTINESCHEMA AND q.TABLE_NAME = r.ROUTINENAME
    WHERE
        q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
        AND t.TABNAME IS NULL
        AND r.ROUTINENAME IS NULL
    )
)
;

DELETE FROM "SAVETODB_DEV"."TABLE_FORMATS" WHERE "TABLE_SCHEMA" = 'SAVETODB_DEV' AND "TABLE_NAME" = 'EVENT_HANDLERS';

INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', '<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.EVENT_HANDLERS">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the INTEGER datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(50) datatype." type="String" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="255" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(255) datatype." type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-32768" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="32767" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the SMALLINT datatype." type="String" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-32768" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.Formula2" value="32767" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.ErrorMessage" value="The column requires values of the SMALLINT datatype." type="String" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="St' || 'ring" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$12" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$12" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$12" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

-- 7.19

DELETE FROM "SAVETODB_DEV"."TABLE_FORMATS" WHERE "TABLE_SCHEMA" = 'SAVETODB_DEV' AND "TABLE_NAME" = 'PARAMETER_VALUES';

INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', '<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.PARAMETER_VALUES">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the INTEGER datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="PARAMETER_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="SELECT_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="17.86" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="SELECT_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String" />
<column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="SELECT_TYPE" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$9" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$9" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$9" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$9" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

ALTER TABLE "SAVETODB_DEV"."EVENT_HANDLERS" ALTER COLUMN "HANDLER_NAME" DROP NOT NULL;

INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,PROCEDURE,CODE,MERGE');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE');
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

DELETE FROM "SAVETODB_DEV"."TABLE_FORMATS" WHERE "TABLE_SCHEMA" = 'SAVETODB_DEV' AND "TABLE_NAME" = 'EVENT_HANDLERS';

INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', '<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.EVENT_HANDLERS">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the INTEGER datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(50) datatype." type="String" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(128) datatype." type="String" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="255" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the VARCHAR(255) datatype." type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-32768" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="32767" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the SMALLINT datatype." type="String" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-32768" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.Formula2" value="32767" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.ErrorMessage" value="The column requires values of the SMALLINT datatype." type="String" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="St' || 'ring" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$12" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$12" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$12" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
